#!/usr/bin/env node
/*!
 * gitmars v7.0.0-beta.30
 * 这是一个git工作流工具
 * (c) 2021-2024 saqqdy<https://github.com/saqqdy> 
 * Released under the MIT License.
 */
import { program } from 'commander';
import { select } from '@inquirer/prompts';
import to from 'await-to-done';
import { createArgs, printQrcode } from '@gitmars/utils';
import { getPreAuthQrCode, getAuthorizerListWithAllDetail } from '@gitmars/api';
import lang from './common/local.mjs';
import { cmdConfig } from './conf/miniprogram.mjs';

const { t } = lang;
const { args, options } = cmdConfig;
program.name("gitm miniprogram").usage(
  "[miniprogram] [-e --env [env]] [--api-env [apiEnv]] [-mp --miniprogram [miniprogram]] [-des --description [description]] [-a --app [app]] [-d --data <data>] [-c --confirm]"
).description(t("miniprogram command"));
if (args.length > 0)
  program.arguments(createArgs(args));
options.forEach((o) => {
  program.option(o.flags, o.description, o.defaultValue);
});
program.action(async (miniprogram, opt) => {
  if (miniprogram === "auth") {
    const authUrl = await getPreAuthQrCode();
    await printQrcode(authUrl);
  } else if (!miniprogram) {
    const { list } = await getAuthorizerListWithAllDetail({ limit: -1 });
    [, miniprogram = ""] = await to(
      select({
        message: t("Select the application to build"),
        choices: list.map(({ authorizer_info: info, authorizer_appid }) => ({
          name: info.nick_name,
          value: authorizer_appid
        }))
      })
    );
  }
  console.log(1001, miniprogram, opt);
});
program.parse(process.argv);
