#!/usr/bin/env node
/*!
 * gitmars v7.0.0-beta.30
 * 这是一个git工作流工具
 * (c) 2021-2024 saqqdy<https://github.com/saqqdy> 
 * Released under the MIT License.
 */
import { program } from 'commander';
import sh from 'shelljs';
import { createArgs, spawnSync } from '@gitmars/utils';
import lang from './common/local.mjs';
import { cmdConfig } from './conf/unlink.mjs';

const { t } = lang;
const { args, options } = cmdConfig;
program.name("gitm unlink").usage("[name]").description(t("Unlinking local package"));
if (args.length > 0)
  program.arguments(createArgs(args));
options.forEach((o) => {
  program.option(o.flags, o.description, o.defaultValue);
});
program.action((name) => {
  const isLink = sh.test("-L", `./node_modules/${name}`);
  const isExist = sh.test("-e", `./node_modules/${name}_bak`);
  const npmClient = sh.which("yarn") ? "yarn" : "npm";
  if (!name) {
    spawnSync(npmClient, ["unlink"]);
    sh.echo(t("Processing completed"));
    process.exit(0);
  } else if (isLink) {
    spawnSync(npmClient, ["unlink", name]);
  } else {
    sh.echo(t("No softlink found, please confirm entering the correct name"));
  }
  if (isExist) {
    sh.mv(`./node_modules/${name}_bak`, `./node_modules/${name}`);
  }
  sh.echo(t("Processing completed"));
});
program.parse(process.argv);
